bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 35. Aventiure
___________________________________________________
| ### <Do> rief von Tenemarche der margrave Irinch ### ich han <· f> ere lazzen nv lange miniv dinch ### vnde han in volches stvermen des besten vil getan ### nv brinch mir min gewæffen ia wil ich Hagenen bestan ### Daz wil ich widerraten sprach do Hagene ### so heiz vf hoher wichen der Hivnen degene ### gespringet iwer zwene oder dri in den sal ### di sende ich vil vngesvnde di stiegen wider hin ce tal
###### 2027 | ### Dar vmbe ichz niht laze sprach aber Irinch ### ich han ovch ê versv^chet sam sorchlichiv dinch ### ia wil ich mit dem swerte dich einen bestan ### waz hilfet vebermveten daz dv mit rede hast getan
| ### Do wart gewaffent <balde> der degen Irinch ### vnde Irnfrit von Dveringen ein chvener ivngelinch ### vnd Hawart der vil starche wol mit tvsent man ### swes Irinch begvnde si woldens alles im gestan
###### 2029 | ### Do sah der videlære eine vil groze shar ### di mit Iringe gewaffent chomen dar ### si trvgen vf gebvnden vil manegen helm gvt ### do wart der chvene Volker ein teil vil zornech gemvt
###### 2030 | ### Seht ir vrivnt Hagene dort Iringen gan ### der ivh mit dem swerte lobt eine bestan ### wi zement helde lvgene ich wil vnprisen daz ### ez gent mit im gewaffent wol tvsent recken oder baz [394a]
| ### Nv <heizet> mich niht liegen sprah Hawartes man ### ich wilz gerne leisten swaz ich gelobt han ### dvrh deheine vorhte wil iches ab gan ### swi grivlich si nv Hagene ich wil in eine bestan
###### 2032 | ### Ze fvzen bot sich Irinch magen vnd man ### do in eine liezen di recken bestan ### daz taten si vngerne wand in was wol bechant ### der vebermvete Hagene vzer Bvrgonden lant
###### 2033 | ### Do bat er si so lange daz ez sit geschach ### do daz ingesinde den willen sin ersach ### daz er warp nach eren do liezen si in gan ### do wart von in beiden ein grimmez striten getan
| ### Irinch von Tenemarche vil hohe trvch den ger ### sich dachte mit dem schilde der tiwer degen her ### do lief er vf ce Hagenen vaste fver den sal ### do hvb sich von den degenen ein vil grozlicher schal
###### 2035 | ### Do shvzen si di gere mit chrepfte von der hant ### dvrch di vesten shilde vf liehtez ir gewant ### daz di gerstangen vil hohe dræten dan ### do griffen zv den swerten di zwene grimme chvene man
###### 2036 | ### Des chvenen Hagen ellen daz was starche groz ### do slvch ovch vf <in> Irinc daz al daz hvs erdoz ### palas vnd tvrne erhvllen nach ir slegen ### done chonde niht verenden des sinen willen der degen
| ### Irinch der lie Hagenen vnverwndet stan ### zv dem videlære gahen er began ### er wande er moehte in twingen mit sinen herten slegen ### do chonde sich wol beshermen Volker der degen
###### 2038 | ### Do slvch der videlære daz veber des schildes rant ### dræte daz gespenge von Volkeres hant ### den liez er do beliben ez was ein vebel man ### do lief er Gventheren von den Bvrgonden an
###### 2039 | ### Do was ir ietweder ce strite starch genvch ### swaz Gventher vnd Irinch vf ein ander slvch ### daz brahte niht [394b] von wnden daz vliezende plvt ### daz behvte ir gewæffen daz was starch vnde gvt
| ### Gventhern er lie beliben vnd lief Gernoten an ### daz fiwer vz den ringen er howen im began ### do hete von Bvrgonden der starche Gernot ### den chvenen Iringen erslagen næhelichen tot
###### 2041 | ### Do spranch er von dem fversten snel er was genvch ### der Bvrgonden viere der helt vil balde slvch ### des edeln ingesindes von Wormez vber Rin ### done chvnde Giselher nimmer zorneger gesin
###### 2042 | ### Got weiz her Irinch sprach Giselher daz chint ### ir mvezet mir di gelten di vor iv tot sint ### gelegen hi ce stvnde do lief er in an ### er slvch den Tenlender daz er mvse da bestan
| ### Er shoz vor sinen handen nider in daz plvt ### daz si alle wolden wænen daz der helt gvt ### ce strite nimmer mere geslvch einen slach ### Irinch <doh> ane wnden hie vor Giselhern lach
###### 2044 | ### Von des swertes doze vnde von des helmes chlanch ### waren sine witze worden harte chranch ### daz sich der degen chvene des lebens niht <versan> ### daz het mit sinen chrepften der starche Giselher getan
###### 2045 | ### Do im begonde entwichen von dem hovbte der doz ### den er ê da dolte von dem slage groz ### er dahte ich pin noch lebende vnd ninder wnt ### nv ist mir aller erst daz ellen Giselheres chvnt
| ### Do hort er beidenthalben di viande stan ### wisten si div mære im wære noch mer getan ### ovch het er Giselheren da bi im vernomen ### er dahte wi er solde von den vianden chomen
###### 2047 | ### Wi rehte tobeliche er vz dem plvot spranch ### siner snelheite er mohte sagen danch ### do lief er vz dem hvse da er aber Hagen vant ### vnd slvch im slege grimme mit siner [395a] ellenthafter hant
###### 2048 | ### Do dahte Hagen dv mvst des todes wesen ### dich en vride der vbel tivel dvne chanst niht genesen ### doch wnte Irinch Hagenen dvrch sinen helmhvt ### daz tet der helt mit Waschen daz was ein waffen also gvt
| ### Do der herre Hagene der wnden enpfant ### do erwagt im vngefvge daz swert an siner hant ### al da mvse im entwichen der Hawartes man ### hin nider vo den stiegen Hagen im volgen began
###### 2050 | ### Irinch der vil chvene den schilt veber swanch ### vnde wære div selbe stiege drier stiegen lanch ### di wile liez in Hagen ni slahen einen slach ### hey waz roter vanchen ob sinem hovbte galach
###### 2051 | ### Wider zv den sinen chom Irinch wol gesvnt ### do wrden disiv mære Criemhilde rehte chvnt ### waz er von Tronege Hagenen mit sinem strite het getan ### des im div chveneginne vil hohe danchen began
| ### Nv lon dir got Irinch vil mære helt gvt ### dv hast mir wol getroestet daz herce vnde ovch den mvt ### nv sihe <ih> rot von plvte Hagenen sin gewant ### Criemhilt nam im selbe den schilt vor liebe von der hant
###### 2053 | ### Ir mvget im mazen danchen so sprach Hagene ### wold erz noch versv^chen daz zæme degene ### chom er danne hinnen so wære er chvener man ### div wnde frvmt ivch chleine die ich von im enpfangen han
###### 2054 | ### Daz ir von miner wnden di ringe sehet rot ### daz hat mich erreizet vf maniges mannes tot ### ich pin aller erst erzvernet als ein vnverzaget man ### mir hat der degen Irinch shaden chleinen noch getan
| ### Do stvnt gegen dem winde Irinch von Tenelant ### er chvlte sich in ringen den helm er ab gebant ### do sprachen al di livte sin ellen wære gvt ### des het der marchgrave einen riche hohen mvt [395b]
###### 2056 | ### Aber sprach do Irinch mine vrivnt wizet daz ### daz ir mich wafent schiere ich wilz versvchen baz ### ob ich noch mvege betwingen den vebermveten man ### sin schilt was verhowen einen bezern er gewan
###### 2057 | ### Vil schiere wart der recke do gewaffent baz ### einen ger vil starchen nam er dvrch den haz ### da mit er aber wolde Hagenen dort bestan ### do warte im vientliche der mortgrimmege man
| ### Sin mohte niht erbiten Hagen der degen ### er lief im hin engegene mit shvezen vnde mit slegen ### di stiegen vz an ein ende sin zorn der was groz ### Irinch siner sterche do vil wenech genoz
###### 2059 | ### Si slvgen dvrch di <shilde> daz iz lovgen began ### von fiwer roten wnden der Hawartes man ### wart von <Hagen> swerte chrepftechlichen wnt ### dvrh schilt vnd dvrch di brvenne des er wart nimmer mer gesvnt
###### 2060 | ### Do der degen Irinch der wnden enpfant ### den schilt er baz do rvchte veber div helmbant ### des schaden in dvhte der volle den er da gewan ### sit tet im aber mer des kvenech Gvntheres man
| ### Hagen vor sinen fvzen einen ger ligen vant ### er shoz vf Iringen den helt von <Tenelant> ### daz im von dem hovbte div stange ragete dan ### im hete der recke Hagene den grimmen ende getan
###### 2062 | ### Irinch mvst entwichen zv den von Tenelant ### ê daz man do dem degen den helm ab gebant ### man brach den ger von hovbte do nahete im der tot ### daz weinten sine mage des gie in wærliche not
###### 2063 | ### Do chom div chveneginne veber in gegan ### den starchen Iringen chlagen si began ### si weinte sine wnden ez was ir grimme leit ### do sprach vor sinen magen der recke chvene vnt gemeit
| ### Lat di chlage beliben vil <herlich> wip ### waz hilfet iwer weinen ia [396a] mvz ich minen lip ### verliesen von den wnden di ich enpfangen han ### der tot wil niht langer iv vnd Eceln dienen lan
###### 2065 | ### Er sprach zv den dveringen vnt ce den von Tenelant ### di gabe sol enpfahen iwer deheines hant ### von der chveneginne ir liehtez golt vil rot ### vnde bestet ir Hagenen ir mvezet chiesen den tot
###### 2066 | ### Sin varwe was erblichen des todes zeichen trvch ### Irinch der vil chvene ez was in leit genvch ### genesen niht enchvnde der Hawartes man ### do mvst ez an ein striten von dem von Tenemarche gan
| ### Irnfrit vnde Hawart sprvngen fver daz gadem ### wol mit tvsent helden vil vngefvegen cradem ### hort man allenthalben chrepftech vnde groz ### hey waz man scharpfer gere zv den Bvrgonden shoz
###### 2068 | ### Irnfrit der chvene lief an den spilman ### des er den schaden grozen von siner hant gewan ### der edel videlære den lantgraven slvch ### dvrch einen helm vesten ia was er grimme genvch
###### 2069 | ### Do slvch der herre Irnfrit den chvenen spilman ### daz im mvsen brestn div ringes gespan ### vnt daz sich beschvte div brvenne fiwer rot ### doch vil der lantgrave vor dem videlære tot
| ### <Hawart> vnde Hagene cesamne waren chomen ### er mohte wnder chiesen ders hete war genomen ### div swert genote vielen den helden an der hant ### Hawart mvst ersterben von dem vzer Bvrgonden lant
###### 2071 | ### Do di Tenen vnde di dverengen ir herren sahen tot ### do hvb sich vor dem hvse ein vreislichiv not ### ê si di tver gewnnen mit ellenthafter hant ### des wart da verhowen [396b] vil manech helm vnde rant
###### 2072 | ### Wichet sprach do Volker vnde lat si her in gan ### ez ist svs vnverendet des si da habent wan ### si mvezen drinne ersterben in vil chvrcer zit ### si erarnent mit dem tode daz in div chveneginne git
| ### Do di vebermveten chomen in den sal ### vil manegem wart daz hovbt geneiget so ze tal ### daz er mvse ersterben von ir swinden slegen ### wol streit der chvene Gernot sam tet ovch Giselher der degen
###### 2074 | ### Tvsent vnde viere chomen in daz hvs ### von swerten sach man blicken vil manegen swinden svs ### sit wrden doch di recken alle drinne erslagen ### man mohte michel wnder von den Bvergonden sagen
###### 2075 | ### Dar nach wart ein stille do der shal verdoz ### daz plvot allenthalben dvrh div loecher vloz ### vnt da cen rigelsteinen von den toten man ### daz heten di von Rine mit grozem ellen getan
| ### Do sazen aber rwoen di von Bvergonden lant ### div waffen <den> schilden leitens vz der hant ### do stvnt noch vor dem tvrne der chvene spilman ### er warte ob iemen wolde noch zv zin mit strite gan
###### 2077 | ### Der kvenech chlagete sere sam tet ovch sin wip ### megede vnd vrowen di qvelten da den lip ### ich wæne des daz hete der tot vf si gesworn ### des wart noch vil der recken von den gesten da verlorn

<<< Übersicht <<< vorige Seite nächste Seite >>>